package com.dayou.brokerage;

import com.dayou.bo.BrokerageDetailBO;
import com.dayou.brokerage.Factory.BrokerageCalculateFactory;
import com.dayou.brokerage.constants.BrokerageRule;
import com.dayou.brokerage.handler.MarketerBrokerageHandler;
import com.dayou.brokerage.validator.BrokerageValidator;
import com.dayou.dto.ItemDTO;
import com.dayou.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;

import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.Date;

/**
 * 类说明：
 *
 * @author: wucl
 * @since: 2023/3/3
 * created with IntelliJ IDEA.
 */
public abstract class BrokerageCalculateSupport implements BrokerageCalculator ,BrokerageCalculateFactory {

    @Autowired
    private BrokerageValidator brokerageValidator;

    @Autowired
    private MarketerBrokerageHandler marketerBrokerageHandler;

    @Override
    public BrokerageCalculator getCalculator(BrokerageRule rule){
        switch (rule){
            case LAND_MARKETER_RULE:
                return marketerBrokerageHandler;
            case LAND_OTHER_RULE:
                return null;
        }
        return null;
    }
    /**
     * 校验项目提成状态
     * @param brokerageDetailBo
     * @return
     */
    protected void checkItemBrokerageStatus(BrokerageDetailBO brokerageDetailBo){
        brokerageValidator.checkItemBrokerageStatus(brokerageDetailBo);
    }

    /**
     * 市场人员预提校验
     * @param brokerageDetailBo
     * @return
     */
    protected void checkMarketerPredictBrokerage(BrokerageDetailBO brokerageDetailBo){
        @NotNull
        BigDecimal paymentTarget = brokerageDetailBo.getPaymentTarget();
        BigDecimal avgMonthTarget = paymentTarget.divide(brokerageValidator.monthOfYear, 2, RoundingMode.HALF_UP);
        int month = DateUtils.getMonth(new Date());
        //当月应完成回款金额
        BigDecimal brokerageTarget = avgMonthTarget.multiply(new BigDecimal(month));
        brokerageValidator.checkMarketerPredictBrokerage(brokerageDetailBo,brokerageTarget);
    }

    public abstract BrokerageDetailBO predictAmount(BrokerageDetailBO brokerageDetailBo);
}
