package com.dayou.brokerage.handler;

import com.dayou.bo.BrokerageDetailBO;
import com.dayou.brokerage.BrokerageCalculateSupport;
import com.dayou.brokerage.BrokerageCalculator;
import com.dayou.brokerage.Factory.BrokerageCalculateFactory;
import com.dayou.brokerage.config.BrokerageMarketerRatioSet;
import com.dayou.brokerage.constants.BrokerageMode;
import com.dayou.brokerage.constants.BrokerageRule;
import com.dayou.dto.ItemDTO;
import com.dayou.exception.BusinessException;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.math.BigDecimal;

/**
 * 类说明：
 *
 * @author: wucl
 * @since: 2023/3/6
 * created with IntelliJ IDEA.
 */
@Component
@Slf4j
public class MarketerBrokerageHandler extends BrokerageCalculateSupport implements BrokerageCalculator{

    @Autowired
    private BrokerageMarketerRatioSet brokerageMarketerRatioSet;

    @Override
    public BrokerageDetailBO predictAmount(BrokerageDetailBO bo) {
        String mergeKey = bo.mergeKey();
        BigDecimal ratio = brokerageMarketerRatioSet.getRatioList().get(mergeKey);
        bo.setBrokerageRule(BrokerageRule.LAND_MARKETER_RULE.getCode());
        bo.setBrokerageMode(BrokerageMode.PERSONAL.getCode());
        bo.setAdvanceAmount(BigDecimal.ZERO);
        bo.setPredictAmount(BigDecimal.ZERO);
        bo.setActualAmount(BigDecimal.ZERO);
        bo.setRate(ratio);
        if (bo.getAmount()!=null && ratio !=null){
            checkItemBrokerageStatus(bo);
            try {
                checkMarketerPredictBrokerage(bo);
                //todo 可提成金额计算规则这个地方应该要改
                bo.setPredictAmount(bo.getAmount().multiply(ratio));
                //todo 实际提成金额可能与可提成金额不一致，可能存在考核指标打折
                bo.setActualAmount(bo.getPredictAmount());
                bo.setMarketerAdvanceBrokerageAble(Boolean.TRUE);
            } catch (BusinessException e) {
                log.info("项目id:[{}],客户经理id：[{}],[{}]",bo.getId(),bo.getUserId(),e.getMessage());
            }
        }else {
            log.info("项目id:[{}],合同金额：[{}],提成系数：[{}],[未填写合同金额或未设置提成系数，无法计算客户经理提成]",bo.getId(),bo.getAmount(),ratio);
        }
        return bo;

    }

    @Override
    public BigDecimal actualAmount(ItemDTO itemDTO) {
        return null;
    }

    @Override
    public BigDecimal advanceAmount() {
        return null;
    }

    @Override
    public BigDecimal residueAmount() {
        return null;
    }


}
