package com.dayou.brokerage.interceptor;

import com.dayou.brokerage.annotation.DoBrokerage;
import com.dayou.brokerage.constants.BrokerageRule;
import com.dayou.service.IItemBrokerageGeneralService;
import com.dayou.service.IItemService;
import lombok.Setter;
import lombok.extern.slf4j.Slf4j;
import org.aopalliance.intercept.MethodInterceptor;
import org.aopalliance.intercept.MethodInvocation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.lang.reflect.Method;

import static com.dayou.brokerage.constants.BrokerageRule.LAND_MARKETER_RULE;

/**
 * 类说明：
 *
 * @author: wucl
 * @since: 2023/3/7
 * created with IntelliJ IDEA.
 */
@Slf4j
@Component
public class BrokerageInterceptor implements MethodInterceptor {

    //注入service Bean 后，拦截该bean中的方法失效。
    private IItemService iItemService;

    @Override
    public Object invoke(MethodInvocation methodInvocation) throws Throwable {
        Method method = methodInvocation.getMethod();
        DoBrokerage annotation = method.getAnnotation(DoBrokerage.class);
        Object result = methodInvocation.proceed();
        if (annotation!=null && annotation.rule() == LAND_MARKETER_RULE){
            if (result instanceof Long){
                iItemService.createBrokerageGeneral((Long) result);
                log.info("created marketer brokerage general and detail");
            };
        }
        return result;
    }
}
