package com.dayou.brokerage.validator;

import cn.hutool.core.util.StrUtil;
import com.dayou.bo.BrokerageDetailBO;
import com.dayou.brokerage.config.BrokerageConfig;
import com.dayou.brokerage.constants.BrokerageRule;
import com.dayou.brokerage.constants.BrokerageState;
import com.dayou.enums.GlobalConfigEnum;
import com.dayou.exception.ErrorCode;
import com.dayou.service.IGlobalConfigService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.support.DefaultListableBeanFactory;
import org.springframework.context.ApplicationContext;

import javax.annotation.Nullable;
import java.math.BigDecimal;

/**
 * 类说明：提成校验器
 *
 * @author: wucl
 * @since: 2023/3/3
 * created with IntelliJ IDEA.
 */
public class BrokerageValidator {

    @Autowired
    private ApplicationContext applicationContext;

    @Autowired
    private IGlobalConfigService globalConfigService;

    @Nullable
    public BigDecimal monthOfYear;

    @Nullable
    public BigDecimal nonMarketerMonthBrokerage;

    //todo 通过切面实现校验器更新
    public void reloadBrokerageValidator(){
        DefaultListableBeanFactory defaultListableBeanFactory = (DefaultListableBeanFactory) applicationContext.getAutowireCapableBeanFactory();
        defaultListableBeanFactory.destroySingleton("brokerageValidator");
        defaultListableBeanFactory.getBean("brokerageValidator",BrokerageValidator.class);
    }
    //校验客户经理对此单是否可以预提
    public void checkMarketerPredictBrokerage(BrokerageDetailBO brokerageDetailBo, BigDecimal brokerageTarget){
        if (brokerageDetailBo.getCurrentPayment().compareTo(brokerageTarget)== -1){
            ErrorCode.throwBusinessException(ErrorCode.BROKERAGE_ITEM_STATE_ERROR2);
        }
    }

    //校验项目提成状态
    public void checkItemBrokerageStatus(BrokerageDetailBO brokerageDetailBo){
        if (StrUtil.equals(BrokerageState.CLOSED.getCode(),brokerageDetailBo.getItemBrokerageStatus()) ||
                StrUtil.equals(BrokerageState.FREEZE.getCode(),brokerageDetailBo.getItemBrokerageStatus())){
            ErrorCode.throwBusinessException(ErrorCode.BROKERAGE_ITEM_STATE_ERROR);
        }
        if (StrUtil.equals(BrokerageRule.LAND_OTHER_RULE.getCode(),brokerageDetailBo.getBrokerageRule())
                && StrUtil.equals(BrokerageState.NOT_START.getCode(),brokerageDetailBo.getItemBrokerageStatus())){
            ErrorCode.throwBusinessException(ErrorCode.BROKERAGE_ITEM_STATE_ERROR1);
        }
    }

    public void setStatus(){
        nonMarketerMonthBrokerage = new BigDecimal(globalConfigService.getValue(GlobalConfigEnum.FINANCE.getCode(),
                GlobalConfigEnum.Finance.NON_MARKETER_MONTH_BROKERAGE.getCode()));
        monthOfYear = new BigDecimal(globalConfigService.getValue(GlobalConfigEnum.SYS.getCode(),
                GlobalConfigEnum.Sys.MONTH_OF_YEAR.getCode()));
    }

    //todo m3 校验参与者是否可继续预提
}
