package com.dayou.service.impl;

import com.dayou.bo.BrokerageDetailBO;
import com.dayou.brokerage.BrokerageCalculateSupport;
import com.dayou.brokerage.BrokerageCalculator;
import com.dayou.brokerage.constants.BrokerageRule;
import com.dayou.brokerage.constants.BrokerageState;
import com.dayou.entity.ItemBrokerageGeneral;
import com.dayou.entity.PaymentCollection;
import com.dayou.entity.UserTarget;
import com.dayou.exception.BusinessException;
import com.dayou.mapper.ItemBrokerageGeneralMapper;
import com.dayou.service.IItemBrokerageDetailService;
import com.dayou.service.IItemBrokerageGeneralService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.dayou.service.IMarketStatService;
import com.dayou.service.IUserTargetService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.dayou.utils.ExcelUtil;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.web.multipart.MultipartFile;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import org.springframework.transaction.annotation.Transactional;
import com.dayou.enums.BatchTaskTypeEnum;

/**
 * <p>
 * 项目提成总表 服务实现类
 * </p>
 *
 * @author wucl
 * @since 2023-03-03
 */
@Slf4j
@Service
public class ItemBrokerageGeneralServiceImpl extends ServiceImpl<ItemBrokerageGeneralMapper, ItemBrokerageGeneral> implements IItemBrokerageGeneralService {


    @Autowired
    private BrokerageCalculator brokerageCalculator;

    @Autowired
    private IUserTargetService userTargetService;

    @Autowired
    private IItemBrokerageDetailService iItemBrokerageDetailService;

    @Autowired
    private IMarketStatService marketStatService;

    @Override
    @SuppressWarnings("unchecked")
    public Page<ItemBrokerageGeneral> selectPage(Page page,ItemBrokerageGeneral itemBrokerageGeneral){
        return this.page(page, new QueryWrapper<ItemBrokerageGeneral>(itemBrokerageGeneral));
    }


    @Override
    public ItemBrokerageGeneral detail(Long id){
        return this.getById(id);
    }

    @Override
    public Boolean add(ItemBrokerageGeneral itemBrokerageGeneral){
        return  this.save(itemBrokerageGeneral);
    }

    @Override
    public Boolean update(ItemBrokerageGeneral itemBrokerageGeneral){
        return  this.updateById(itemBrokerageGeneral);
    }

    @Override
    public Boolean delete(Long id){
        //逻辑删除
        return this.removeById(id);
    }

    @Transactional
    @Override
    public void doCreateBrokerageGeneral(BrokerageDetailBO bo) {
        BrokerageCalculator calculator = brokerageCalculator.getCalculator(BrokerageRule.LAND_MARKETER_RULE);

        Long userId = bo.getUserId();
        UserTarget userTarget = userTargetService.getOne(new LambdaQueryWrapper<UserTarget>().eq(UserTarget::getUserId,userId));
        if (userTarget==null || userTarget.getPaymentTarget()==null){
            userTarget = new UserTarget();
            userTarget.setPaymentTarget(0d);
            log.info("客户经理id[{}]未设置年回款目标。",userId);
        }

        BigDecimal currentMonthPayment = marketStatService.currentMonthPayment(userId);
        BigDecimal paymentTarget = new BigDecimal(userTarget.getPaymentTarget());
        bo.setCurrentPayment(currentMonthPayment);
        bo.setPaymentTarget(paymentTarget);
        bo.setItemBrokerageStatus(BrokerageState.NOT_START.getCode());

        bo = calculator.predictAmount(bo);
        ItemBrokerageGeneral general = ItemBrokerageGeneral.builder()
                .itemId(bo.getId())
                .marketerBrokerageAmount(bo.getPredictAmount())
                .marketerAdvanceBrokerageAble(bo.getMarketerAdvanceBrokerageAble())
                .brokeragePredictAmount(bo.getPredictAmount())
                .brokerageActualAmount(BigDecimal.ZERO)
                .brokerageRate(bo.getRate()).build();
        this.save(general);
        bo.setGeneralId(general.getId());
        iItemBrokerageDetailService.save(bo);
    }
}
